"use strict";
(self["webpackChunk_JUPYTERLAB_CORE_OUTPUT"] = self["webpackChunk_JUPYTERLAB_CORE_OUTPUT"] || []).push([["1843"], {
32670(__unused_rspack_module, __webpack_exports__, __webpack_require__) {
__webpack_require__.d(__webpack_exports__, {
  createGitGraphServices: () => (/* reexport safe */ _chunk_4F5CHEZ2_mjs__rspack_import_0.b)
});
/* import */ var _chunk_4F5CHEZ2_mjs__rspack_import_0 = __webpack_require__(32639);
/* import */ var _chunk_TCCFYFTB_mjs__rspack_import_1 = __webpack_require__(37503);





},

}]);
//# sourceMappingURL=1843.fa86313a3e1f53ad.js.map?v=fa86313a3e1f53ad