"use strict";
(self["webpackChunk_JUPYTERLAB_CORE_OUTPUT"] = self["webpackChunk_JUPYTERLAB_CORE_OUTPUT"] || []).push([["9513"], {
7470(__unused_rspack_module, exports, __webpack_require__) {
var __webpack_unused_export__;


var m = __webpack_require__(92074);
if (true) {
  exports.createRoot = m.createRoot;
  __webpack_unused_export__ = m.hydrateRoot;
} else { var i }


},

}]);
//# sourceMappingURL=9513.a24640cff346c9c7.js.map?v=a24640cff346c9c7