"use strict";
(self["webpackChunk_JUPYTERLAB_CORE_OUTPUT"] = self["webpackChunk_JUPYTERLAB_CORE_OUTPUT"] || []).push([["1445"], {
82153(__unused_rspack_module, __webpack_exports__, __webpack_require__) {
__webpack_require__.d(__webpack_exports__, {
  createTreemapServices: () => (/* reexport safe */ _chunk_B2363JML_mjs__rspack_import_0.d)
});
/* import */ var _chunk_B2363JML_mjs__rspack_import_0 = __webpack_require__(29687);
/* import */ var _chunk_TCCFYFTB_mjs__rspack_import_1 = __webpack_require__(37503);





},

}]);
//# sourceMappingURL=1445.9d5c8f19422fdbd8.js.map?v=9d5c8f19422fdbd8