"use strict";
(self["webpackChunk_JUPYTERLAB_CORE_OUTPUT"] = self["webpackChunk_JUPYTERLAB_CORE_OUTPUT"] || []).push([["1444"], {
5471(__unused_rspack_module, __webpack_exports__, __webpack_require__) {
__webpack_require__.d(__webpack_exports__, {
  createInfoServices: () => (/* reexport safe */ _chunk_FRFDVMJY_mjs__rspack_import_0.v)
});
/* import */ var _chunk_FRFDVMJY_mjs__rspack_import_0 = __webpack_require__(36542);
/* import */ var _chunk_TCCFYFTB_mjs__rspack_import_1 = __webpack_require__(37503);





},

}]);
//# sourceMappingURL=1444.d135f931d5c65fb6.js.map?v=d135f931d5c65fb6