"use strict";
(self["webpackChunk_JUPYTERLAB_CORE_OUTPUT"] = self["webpackChunk_JUPYTERLAB_CORE_OUTPUT"] || []).push([["7815"], {
69370(__unused_rspack_module, __webpack_exports__, __webpack_require__) {
__webpack_require__.d(__webpack_exports__, {
  createArchitectureServices: () => (/* reexport safe */ _chunk_UMXZTB3W_mjs__rspack_import_0.S)
});
/* import */ var _chunk_UMXZTB3W_mjs__rspack_import_0 = __webpack_require__(90856);
/* import */ var _chunk_TCCFYFTB_mjs__rspack_import_1 = __webpack_require__(37503);





},

}]);
//# sourceMappingURL=7815.62cd4c93f9cf2aa2.js.map?v=62cd4c93f9cf2aa2