"use strict";
(self["webpackChunk_JUPYTERLAB_CORE_OUTPUT"] = self["webpackChunk_JUPYTERLAB_CORE_OUTPUT"] || []).push([["7543"], {
12410(__unused_rspack_module, __webpack_exports__, __webpack_require__) {
__webpack_require__.d(__webpack_exports__, {
  diagram: () => (diagram)
});
/* import */ var _chunk_B4BG7PRW_mjs__rspack_import_0 = __webpack_require__(74955);
/* import */ var _chunk_FMBD7UC4_mjs__rspack_import_1 = __webpack_require__(33176);
/* import */ var _chunk_55IACEB6_mjs__rspack_import_2 = __webpack_require__(62904);
/* import */ var _chunk_QN33PNHL_mjs__rspack_import_3 = __webpack_require__(67313);
/* import */ var _chunk_N4CR4FBY_mjs__rspack_import_4 = __webpack_require__(86528);
/* import */ var _chunk_QXUST7PY_mjs__rspack_import_5 = __webpack_require__(18081);
/* import */ var _chunk_HN2XXSSU_mjs__rspack_import_6 = __webpack_require__(49163);
/* import */ var _chunk_JZLCHNYA_mjs__rspack_import_7 = __webpack_require__(45755);
/* import */ var _chunk_CVBHYZKI_mjs__rspack_import_8 = __webpack_require__(6152);
/* import */ var _chunk_ATLVNIR6_mjs__rspack_import_9 = __webpack_require__(99010);
/* import */ var _chunk_JA3XYJ7Z_mjs__rspack_import_10 = __webpack_require__(28954);
/* import */ var _chunk_S3R3BYOJ_mjs__rspack_import_11 = __webpack_require__(26391);
/* import */ var _chunk_ABZYJK2D_mjs__rspack_import_12 = __webpack_require__(21065);
/* import */ var _chunk_AGHRB4JF_mjs__rspack_import_13 = __webpack_require__(87724);















// src/diagrams/class/classDiagram-v2.ts
var diagram = {
  parser: _chunk_B4BG7PRW_mjs__rspack_import_0/* .classDiagram_default */._$,
  get db() {
    return new _chunk_B4BG7PRW_mjs__rspack_import_0/* .ClassDB */.NM();
  },
  renderer: _chunk_B4BG7PRW_mjs__rspack_import_0/* .classRenderer_v3_unified_default */.Lh,
  styles: _chunk_B4BG7PRW_mjs__rspack_import_0/* .styles_default */.tM,
  init: /* @__PURE__ */ (0,_chunk_AGHRB4JF_mjs__rspack_import_13/* .__name */.K2)((cnf) => {
    if (!cnf.class) {
      cnf.class = {};
    }
    cnf.class.arrowMarkerAbsolute = cnf.arrowMarkerAbsolute;
  }, "init")
};



},

}]);
//# sourceMappingURL=7543.6cb131885b6b6cdc.js.map?v=6cb131885b6b6cdc