"use strict";
(self["webpackChunk_JUPYTERLAB_CORE_OUTPUT"] = self["webpackChunk_JUPYTERLAB_CORE_OUTPUT"] || []).push([["3531"], {
62262(__unused_rspack_module, __webpack_exports__, __webpack_require__) {
__webpack_require__.d(__webpack_exports__, {
  createPacketServices: () => (/* reexport safe */ _chunk_SJTYNZTY_mjs__rspack_import_0.$)
});
/* import */ var _chunk_SJTYNZTY_mjs__rspack_import_0 = __webpack_require__(63363);
/* import */ var _chunk_TCCFYFTB_mjs__rspack_import_1 = __webpack_require__(37503);





},

}]);
//# sourceMappingURL=3531.0456759d1ee5b874.js.map?v=0456759d1ee5b874